@@ -14,11 +14,11 @@ Genealogy::ObituaryDailyTimes - Compare a Gedcom against the Obituary Daily Time
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -52,33 +52,36 @@ sub new {
 
 =head2 search
 
-   my $obits = Genealogy::ObituaryDailyTimes->new();
+    my $obits = Genealogy::ObituaryDailyTimes->new();
 
-   my @smiths = $obits->search(last => 'Smith');
+    # Returns an array of hashrefs
+    my @smiths = $obits->search(last => 'Smith');	# You must at least define the last name to search for
 
-   print $smiths[0]->{'first'}, "\n";
+    print $smiths[0]->{'first'}, "\n";
 
 =cut
 
 sub search {
 	my $self = shift;
 
-	my %param;
-	if(ref($_[0]) eq 'HASH') {
-		%param = %{$_[0]};
-	} elsif(@_ % 2 == 0) {
-		%param = @_;
+	my %params = (ref($_[0]) eq 'HASH') ? %{$_[0]} : @_;
+
+	if(!defined($params{'last'})) {
+		Carp::carp("Value for 'last' is mandatory");
+		return;
 	}
 
-	return if(scalar keys %param == 0);
+	$self->{'obituaries'} ||= Genealogy::ObituaryDailyTimes::DB::obituaries->new(no_entry => 1);
 
-	$self->{'obituaries'} //= Genealogy::ObituaryDailyTimes::DB::obituaries->new(no_entry => 1) or Carp::croak "Can't open the obituaries database";
+	if(!defined($self->{'obituaries'})) {
+		Carp::croak("Can't open the obituaries database");
+	}
 
 	if(wantarray) {
-		my @obituaries = @{$self->{'obituaries'}->selectall_hashref(\%param)};
+		my @obituaries = @{$self->{'obituaries'}->selectall_hashref(\%params)};
 		return @obituaries;
 	}
-	return $self->{'obituaries'}->fetchrow_hashref(\%param);
+	return $self->{'obituaries'}->fetchrow_hashref(\%params);
 }
 
 =head1 AUTHOR
