@@ -1,7 +1,7 @@
 package Genealogy::ObituaryDailyTimes::DB;
 
 # Author Nigel Horne: njh@bandsman.co.uk
-# Copyright (C) 2015-2020, Nigel Horne
+# Copyright (C) 2015-2021, Nigel Horne
 
 # Usage is subject to licence terms.
 # The licence terms of this software are as follows:
@@ -255,7 +255,7 @@ sub _open {
 				file => $slurp_file
 			)};
 
-			# Don't use blank lines or comments
+			# Ignore blank lines or lines starting with # in the CSV file
 			unless($self->{no_entry}) {
 				@data = grep { $_->{'entry'} !~ /^\s*#/ } grep { defined($_->{'entry'}) } @data;
 			}
@@ -369,12 +369,13 @@ sub selectall_hash {
 			$self->{'logger'}->debug("selectall_hash $query");
 		}
 	}
-	my $key = $query;
-	if(defined($query_args[0])) {
-		$key .= ' ' . join(', ', @query_args);
-	}
+	my $key;
 	my $c;
 	if($c = $self->{cache}) {
+		$key = $query;
+		if(defined($query_args[0])) {
+			$key .= ' ' . join(', ', @query_args);
+		}
 		if(my $rc = $c->get($key)) {
 			# This use of a temporary variable is to avoid
 			#	"Implicit scalar context for array in return"
@@ -454,19 +455,19 @@ sub fetchrow_hashref {
 		if(defined($query_args[0])) {
 			my @call_details = caller(0);
 			$self->{'logger'}->debug("fetchrow_hashref $query: ", join(', ', @query_args),
-				' called from ', $call_details[2] . ' of ' . $call_details[1]);
+				' called from ', $call_details[2], ' of ', $call_details[1]);
 		} else {
 			$self->{'logger'}->debug("fetchrow_hashref $query");
 		}
 	}
 	my $key;
-	if(defined($query_args[0])) {
-		$key = "fetchrow $query " . join(', ', @query_args);
-	} else {
-		$key = "fetchrow $query";
-	}
 	my $c;
 	if($c = $self->{cache}) {
+		if(defined($query_args[0])) {
+			$key = "fetchrow $query " . join(', ', @query_args);
+		} else {
+			$key = "fetchrow $query";
+		}
 		if(my $rc = $c->get($key)) {
 			return $rc;
 		}
@@ -541,7 +542,7 @@ sub AUTOLOAD {
 
 	return if($column eq 'DESTROY');
 
-	my $self = shift or return undef;
+	my $self = shift or return;
 
 	my $table = $self->{table} || ref($self);
 	$table =~ s/.*:://;
